#!/bin/bash
# Connect all lanes to cryosparc


# Path to cryosparcm binary
# Defaults to the wrapper script, which validates the host and supports $CRYOSPARC_HOME
: "${CRYOSPARCM:=/data/project/bio/hpce/software/cryoSPARC/cryosparcm.sh}"

if [[ ! -x "$CRYOSPARCM" ]]; then
    echo "ERROR: Unable to find cryosparcm at $CRYOSPARCM" >&2
    exit 1
fi

LANES=("cpu-daily" "cpu-hourly" "gpu-hourly" "gpu-daily-4h" "gpu-daily" "gpu-general-2d" "gpu-general-2d-100Gb")

success=1
for lane in "${LANES[@]}"; do
    cd "/data/user/${USER}/cryosparc/config/${lane}"
    WORKER=$(sed -nE 's/.*"worker_bin_path" *: *"([^"]*)".*/\1/p' cluster_info.json)
    if [[ ! -x "$WORKER" ]]; then
        echo "ERROR: Worker $WORKER from lane $lane not found." >&2
    else
        echo "$CRYOSPARCM" cluster connect >&2
        "$CRYOSPARCM" cluster connect

        if [[ $? != 0 ]]; then
            echo "ERROR connecting $lane" >&2
            success=0
        fi
        echo >&2

    fi
    cd ~
done

if [[ $success == 0 ]]; then
    echo "Errors occured. See above." >&2
    exit 1
fi
